==> haskell-cracknum-2.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cracknum.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crackNum
version: 2.1
id: crackNum-2.1-5fX00IcnftZC28Gu4dvZOM
key: crackNum-2.1-5fX00IcnftZC28Gu4dvZOM
license: BSD-3-Clause
copyright: Levent Erkok
maintainer: erkokl@gmail.com
author: Levent Erkok
homepage: http://github.com/LeventErkok/CrackNum
synopsis: Crack various integer, floating-point data formats
description:
    Crack HP, SP and DP floats and 8, 16, 32, 64 bit words and integers.
    .
    For details, please see: <http://github.com/LeventErkok/crackNum/>
category: Tools
abi: 12220e61ae39fadc5f52020d5324e27d
exposed: True
exposed-modules:
    Data.Numbers.CrackNum
hidden-modules: Data.Numbers.CrackNum.Utils
                Data.Numbers.CrackNum.Data
import-dirs: /usr/lib/ghc-8.4.3/site-local/crackNum-2.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/crackNum-2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/crackNum-2.1
hs-libraries: HScrackNum-2.1-5fX00IcnftZC28Gu4dvZOM
depends:
    base-4.11.1.0 ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46
    data-binary-ieee754-0.4.4-GMEnBfyxjqq6rJmTySXper
    FloatingHex-0.4-KYnoa1TeuOP3FBMKHxfwLf
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46=58ee7693c3f851924adb1977b480388a
             data-binary-ieee754-0.4.4-GMEnBfyxjqq6rJmTySXper=7311ee61f9f537e52eded25ab07ea8da
             FloatingHex-0.4-KYnoa1TeuOP3FBMKHxfwLf=55f7a4110122120c9cf51b579c32eb56
haddock-interfaces: /usr/share/doc/haskell-cracknum/html/crackNum.haddock
haddock-html: /usr/share/doc/haskell-cracknum/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cracknum-2.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cracknum.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crackNum
version: 2.2
id: crackNum-2.2-JCkoHBHS6oC1nqvC0HZnaY
key: crackNum-2.2-JCkoHBHS6oC1nqvC0HZnaY
license: BSD-3-Clause
copyright: Levent Erkok
maintainer: erkokl@gmail.com
author: Levent Erkok
homepage: http://github.com/LeventErkok/CrackNum
synopsis: Crack various integer, floating-point data formats
description:
    Crack HP, SP and DP floats and 8, 16, 32, 64 bit words and integers.
    .
    For details, please see: <http://github.com/LeventErkok/crackNum/>
category: Tools
abi: a1b41dba4f1043d376116c6b16d551d4
exposed: True
exposed-modules:
    Data.Numbers.CrackNum
hidden-modules: Data.Numbers.CrackNum.Utils
                Data.Numbers.CrackNum.Data
import-dirs: /usr/lib/ghc-8.4.3/site-local/crackNum-2.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/crackNum-2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/crackNum-2.2
hs-libraries: HScrackNum-2.2-JCkoHBHS6oC1nqvC0HZnaY
depends:
    base-4.11.1.0 ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46
    reinterpret-cast-0.1.0-8tHFM4AgpWWIr21ZmPEAzc
    FloatingHex-0.4-KYnoa1TeuOP3FBMKHxfwLf
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             ieee754-0.8.0-KmEF4YGiqmIDu40b1SLx46=58ee7693c3f851924adb1977b480388a
             reinterpret-cast-0.1.0-8tHFM4AgpWWIr21ZmPEAzc=0a46ed9f44a62f6beefa228c9a1b92ba
             FloatingHex-0.4-KYnoa1TeuOP3FBMKHxfwLf=55f7a4110122120c9cf51b579c32eb56
haddock-interfaces: /usr/share/doc/haskell-cracknum/html/crackNum.haddock
haddock-html: /usr/share/doc/haskell-cracknum/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
